@@ -7,8 +7,8 @@ def cmd():
 
 
 @cmd.command()
-@click.argument('key', help="encrypt key string")
-@click.argument('fp', help="file to be encrypted")
+@click.argument('key')
+@click.argument('fp')
 def encrypt(key, fp):
     print(f"{fp} with key {key}")
     encrypt_file(fp, key)
